@@ -8,25 +8,37 @@ class PipelineRun(NamespacedResource):
 
     def __init__(
         self,
+        name=None,
+        namespace=None,
         pipelineref=None,
         params=None,
         service_account_name=None,
+        client=None,
+        yaml_file=None,
         **kwargs,
     ):
         """
         Args:
+            name (str): Name of the pipelinerun
+            namespace (str): Namespace of the pipelinerun
             pipelineref (str): Mandatory: Base pipeline to run pipelineruns
+            client: (DynamicClient): DynamicClient to use.
             params (dict): Optional params to add during triggering a run.
             params can be set/changed based on pipelineref.
             example : params={"param_name1":"param_value1", "param_name2":"param_value2"}
             service_account_name (str): Optional to provide service account
         """
-        super().__init__(**kwargs)
+        super().__init__(
+            name=name,
+            namespace=namespace,
+            client=client,
+            **kwargs,
+        )
         self.pipelineref = pipelineref
         self.params = params
         self.service_account_name = service_account_name
 
-    def to_dict(self) -> None:
+    def to_dict(self):
         super().to_dict()
         if not self.yaml_file:
             if not self.pipelineref:
